# mypy-boto3-customer-profiles

[![PyPI - mypy-boto3-customer-profiles](https://img.shields.io/pypi/v/mypy-boto3-customer-profiles.svg?color=blue)](https://pypi.org/project/mypy-boto3-customer-profiles)
[![PyPI - Python Version](https://img.shields.io/pypi/pyversions/mypy-boto3-customer-profiles.svg?color=blue)](https://pypi.org/project/mypy-boto3-customer-profiles)
[![Docs](https://img.shields.io/readthedocs/mypy-boto3-builder.svg?color=blue)](https://mypy-boto3-builder.readthedocs.io/)
[![PyPI - Downloads](https://img.shields.io/pypi/dw/mypy-boto3-customer-profiles?color=blue)](https://pypistats.org/packages/mypy-boto3-customer-profiles)

![boto3.typed](https://github.com/vemel/mypy_boto3_builder/raw/master/logo.png)

Type annotations for
[boto3.CustomerProfiles 1.17.65](https://boto3.amazonaws.com/v1/documentation/api/1.17.65/reference/services/customer-profiles.html#CustomerProfiles)
service compatible with [VSCode](https://code.visualstudio.com/),
[PyCharm](https://www.jetbrains.com/pycharm/),
[Emacs](https://www.gnu.org/software/emacs/),
[Sublime Text](https://www.sublimetext.com/),
[mypy](https://github.com/python/mypy),
[pyright](https://github.com/microsoft/pyright) and other tools.

Generated by
[mypy-boto3-buider 4.10.0](https://github.com/vemel/mypy_boto3_builder).

More information can be found on
[boto3-stubs](https://pypi.org/project/boto3-stubs/) page and in
[mypy-boto3-customer-profiles docs](https://github.com/vemel/mypy_boto3_builder/service_docs/mypy_boto3_customer_profiles/README.md)

See how it helps to find and fix potential bugs:

![boto3-stubs demo](https://github.com/vemel/mypy_boto3_builder/raw/master/demo.gif)

- [mypy-boto3-customer-profiles](#mypy-boto3-customer-profiles)
  - [How to install](#how-to-install)
  - [Usage](#usage)
    - [VSCode](#vscode)
    - [PyCharm](#pycharm)
    - [Other IDEs](#other-ides)
    - [mypy](#mypy)
    - [pyright](#pyright)
  - [Explicit type annotations](#explicit-type-annotations)
    - [Client annotations](#client-annotations)
    - [Literals](#literals)
    - [Typed dictionaries](#typed-dictionaries)

## How to install

Install `boto3-stubs` for `CustomerProfiles` service.

```bash
python -m pip install boto3-stubs[customer-profiles]
```

## Usage

### VSCode

- Install
  [Python extension](https://marketplace.visualstudio.com/items?itemName=ms-python.python)
- Install
  [Pylance extension](https://marketplace.visualstudio.com/items?itemName=ms-python.vscode-pylance)
- Set `Pylance` as your Python Language Server
- Install `boto-stubs[customer-profiles]` in your environment:
  `python -m pip install 'boto3-stubs[customer-profiles]'`

Both type checking and auto-complete should work for `CustomerProfiles`
service. No explicit type annotations required, write your `boto3` code as
usual.

### PyCharm

- Install `boto-stubs[customer-profiles]` in your environment:
  `python -m pip install 'boto3-stubs[customer-profiles]'`

Both type checking and auto-complete should work for `CustomerProfiles`
service. No explicit type annotations required, write your `boto3` code as
usual. Auto-complete can be slow on big projects or if you have a lot of
installed `boto3-stubs` submodules.

### Other IDEs

Not tested, but as long as your IDE support `mypy` or `pyright`, everything
should work.

### mypy

- Install `mypy`: `python -m pip install mypy`
- Install `boto-stubs[customer-profiles]` in your environment:
  `python -m pip install 'boto3-stubs[customer-profiles]'`
- Run `mypy` as usual

Type checking should work for `CustomerProfiles` service. No explicit type
annotations required, write your `boto3` code as usual.

### pyright

- Install `pyright`: `yarn global add pyright`
- Install `boto-stubs[customer-profiles]` in your environment:
  `python -m pip install 'boto3-stubs[customer-profiles]'`
- Optionally, you can install `boto3-stubs` to `typings` folder.

Type checking should work for `CustomerProfiles` service. No explicit type
annotations required, write your `boto3` code as usual.

## Explicit type annotations

### Client annotations

`CustomerProfilesClient` provides annotations for
`boto3.client("customer-profiles")`.

```python
import boto3

from mypy_boto3_customer_profiles import CustomerProfilesClient

client: CustomerProfilesClient = boto3.client("customer-profiles")

# now client usage is checked by mypy and IDE should provide code auto-complete

# works for session as well
session = boto3.session.Session(region="us-west-1")
session_client: CustomerProfilesClient = session.client("customer-profiles")
```

### Literals

`mypy_boto3_customer_profiles.literals` module contains literals extracted from
shapes that can be used in user code for type checking.

```python
from mypy_boto3_customer_profiles.literals import (
    DataPullMode,
    FieldContentType,
    Gender,
    MarketoConnectorOperator,
    OperatorPropertiesKeys,
    PartyType,
    S3ConnectorOperator,
    SalesforceConnectorOperator,
    ServiceNowConnectorOperator,
    SourceConnectorType,
    StandardIdentifier,
    TaskType,
    TriggerType,
    ZendeskConnectorOperator,
)

def check_value(value: DataPullMode) -> bool:
    ...
```

### Typed dictionaries

`mypy_boto3_customer_profiles.type_defs` module contains structures and shapes
assembled to typed dictionaries for additional type checking.

```python
from mypy_boto3_customer_profiles.type_defs import (
    AddProfileKeyResponseTypeDef,
    AddressTypeDef,
    ConnectorOperatorTypeDef,
    CreateDomainResponseTypeDef,
    CreateProfileResponseTypeDef,
    DeleteDomainResponseTypeDef,
    DeleteIntegrationResponseTypeDef,
    DeleteProfileKeyResponseTypeDef,
    DeleteProfileObjectResponseTypeDef,
    DeleteProfileObjectTypeResponseTypeDef,
    DeleteProfileResponseTypeDef,
    DomainStatsTypeDef,
    FieldSourceProfileIdsTypeDef,
    FlowDefinitionTypeDef,
    GetDomainResponseTypeDef,
    GetIntegrationResponseTypeDef,
    GetMatchesResponseTypeDef,
    GetProfileObjectTypeResponseTypeDef,
    GetProfileObjectTypeTemplateResponseTypeDef,
    IncrementalPullConfigTypeDef,
    ListAccountIntegrationsResponseTypeDef,
    ListDomainItemTypeDef,
    ListDomainsResponseTypeDef,
    ListIntegrationItemTypeDef,
    ListIntegrationsResponseTypeDef,
    ListProfileObjectTypeItemTypeDef,
    ListProfileObjectTypeTemplateItemTypeDef,
    ListProfileObjectTypeTemplatesResponseTypeDef,
    ListProfileObjectTypesResponseTypeDef,
    ListProfileObjectsItemTypeDef,
    ListProfileObjectsResponseTypeDef,
    ListTagsForResourceResponseTypeDef,
    MarketoSourcePropertiesTypeDef,
    MatchItemTypeDef,
    MatchingRequestTypeDef,
    MatchingResponseTypeDef,
    MergeProfilesResponseTypeDef,
    ObjectTypeFieldTypeDef,
    ObjectTypeKeyTypeDef,
    ProfileTypeDef,
    PutIntegrationResponseTypeDef,
    PutProfileObjectResponseTypeDef,
    PutProfileObjectTypeResponseTypeDef,
    S3SourcePropertiesTypeDef,
    SalesforceSourcePropertiesTypeDef,
    ScheduledTriggerPropertiesTypeDef,
    SearchProfilesResponseTypeDef,
    ServiceNowSourcePropertiesTypeDef,
    SourceConnectorPropertiesTypeDef,
    SourceFlowConfigTypeDef,
    TaskTypeDef,
    TriggerConfigTypeDef,
    TriggerPropertiesTypeDef,
    UpdateAddressTypeDef,
    UpdateDomainResponseTypeDef,
    UpdateProfileResponseTypeDef,
    ZendeskSourcePropertiesTypeDef,
)

def get_structure() -> AddProfileKeyResponseTypeDef:
    return {
      ...
    }
```
